<?php

/**
 * @package		Joomla.Administrator
 * @subpackage	com_guestsupport
 * @author		RcaTheme.com https://www.rcatheme.com
 * @copyright	(C) 2025 RcaTheme.com
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace Joomla\Component\Guestsupport\Administrator\View\Forms;

use Joomla\CMS\Factory;
use Joomla\CMS\Uri\Uri;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Helper\ContentHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\View\GenericDataException;
use Joomla\CMS\MVC\View\HtmlView as BaseHtmlView;
use Joomla\CMS\Toolbar\Toolbar;
use Joomla\CMS\Toolbar\ToolbarHelper;
use Joomla\Component\Guestsupport\Administrator\Model\FormsModel;

\defined('_JEXEC') or die;

class HtmlView extends BaseHtmlView
{
	protected $form;
    protected $guide;

    public function display($tpl = null): void
    {
        $model              = $this->getModel();
        $this->form         = $model->getForm();

		$session = Factory::getApplication()->getSession();

		// Add bootstrap modal script
		HTMLHelper::_('bootstrap.modal', '.selector', []);

		// Get guide status from session
		$this->guide = $session->get('com_guestsupport.showguide', '');
		// Empty guide status data on session
		$session->set('com_guestsupport.showguide', '');

        // Check for errors.
        if (\count($errors = $model->getErrors())) {
            throw new GenericDataException(implode("\n", $errors), 500);
        }

        $this->addToolbar();

        parent::display($tpl);
    }

    /**
     * Add the page title and toolbar.
     *
     * @return  void
     *
     * @since   1.6
     */
    protected function addToolbar(): void
    {
        $canDo = ContentHelper::getActions('com_guestsupport');
        $user  = Factory::getApplication()->getIdentity();

        ToolbarHelper::title(Text::_('COM_GUESTSUPPORT_FORMS_TITLE'), 'bookmark guestsupport');

		// Get the toolbar object instance
        $toolbar = Factory::getApplication()->getDocument()->getToolbar();

        if ($canDo->get('core.create')) {
            ToolbarHelper::modal('wt_pro_info_modal', 'icon-new', 'New');
        }

		if ($canDo->get('core.edit.state'))
		{
			$dropdown = $toolbar->dropdownButton('status-group')
				->text('JTOOLBAR_CHANGE_STATUS')
				->toggleSplit(false)
				->icon('fa fa-ellipsis-h')
				->buttonClass('btn btn-action')
				->listCheck(true);
			$childBar = $dropdown->getChildToolbar();
			if ($canDo->get('core.edit'))
            {
                $childBar->edit('forms.edit')
                    ->text('JTOOLBAR_EDIT')
                    ->listCheck(true);
            }
            if ($canDo->get('core.delete'))
            {
                $childBar->delete('forms.delete')
                    ->text('JTOOLBAR_DELETE')
                    ->message('JGLOBAL_CONFIRM_DELETE')
                    ->listCheck(true);
            }
		}
    }
}
